<TS language="et" version="2.0">
<context>
    <name>AboutDialog</name>
    <message>
        <source>About Gridcoin</source>
        <translation>Info Gridcoin'i kohta</translation>
    </message>
    </context>
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Create a new address</source>
        <translation>Loo uus aadress</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Uus</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>Kopeeri märgistatud aadress vahemällu</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Kopeeri</translation>
    </message>
    <message>
        <source>Show &amp;QR Code</source>
        <translation>Näita &amp;QR koodi.</translation>
    </message>
    <message>
        <source>Sign a message to prove you own a Gridcoin address</source>
        <translation>Allkirjasta sõnum Gridcoin'i aadressi omamise tõestamiseks.</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>Kustuta märgistatud aadress loetelust</translation>
    </message>
    <message>
        <source>Address Book</source>
        <translation>Aadressiraamat</translation>
    </message>
    <message>
        <source>These are your Gridcoin addresses for receiving payments. You may want to give a different one to each sender so you can keep track of who is paying you.</source>
        <translation>Need on Sinu Gridcoin'i aadressid maksete vastuvõtmiseks. Soovi korral saad anda igale saatjale eraldi aadressi, et hõlpsamini omada ülevaadet, et kellelt mündid laekuvad.</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Kustuta</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation>Kopeeri &amp;Silt</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Muuda</translation>
    </message>
    </context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation>Märge</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Aadress</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(märge puudub)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation>Salafraasi dialoog</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation>Sisesta salafraas</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>Uus salafraas</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>Korda salafraasi</translation>
    </message>
    <message>
        <source>Enter the new passphrase to the wallet.&lt;br/&gt;Please use a passphrase of &lt;b&gt;ten or more random characters&lt;/b&gt;, or &lt;b&gt;eight or more words&lt;/b&gt;.</source>
        <translation>Sisesta uus salafraas rahakotti.&lt;br/&gt;Kasuta salafraasi millles on&lt;b&gt;kümme või rohkem juhuslikku sümbolit&lt;b&gt;,või&lt;b&gt;kaheksa või rohkem sõna&lt;b/&gt;.</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation>Krüpteeri rahakott</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation>Antud operatsioon vajab rahakoti lahtilukustamiseks salafraasi.</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>Ava rahakoti lukk</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation>Vaheta salafraasi</translation>
    </message>
    <message>
        <source>Enter the old and new passphrase to the wallet.</source>
        <translation>Sisesta rahakoti vana ning uus salafraas.</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation>Kinnita rahakoti krüpteerimine.</translation>
    </message>
    <message>
        <source>Are you sure you wish to encrypt your wallet?</source>
        <translation>Kas oled kindel, et soovid rahakoti krüpteerida?</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation>Rahakott krüpteeritud</translation>
    </message>
    <message>
        <source>IMPORTANT: Any previous backups you have made of your wallet file should be replaced with the newly generated, encrypted wallet file. For security reasons, previous backups of the unencrypted wallet file will become useless as soon as you start using the new, encrypted wallet.</source>
        <translation>TÄHTIS: Kõik varasemad rahakoti varundfailid tuleks üle kirjutada äsja loodud krüpteeritud rahakoti failiga. Turvakaalutlustel tühistatakse krüpteerimata rahakoti failid alates uue, krüpteeritud rahakoti, kasutusele võtust.</translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation>Rahakoti krüpteerimine ebaõnnestus</translation>
    </message>
    <message>
        <source>Wallet encryption failed due to an internal error. Your wallet was not encrypted.</source>
        <translation>Rahakoti krüpteerimine ebaõnnestus sisemise tõrke tõttu. Sinu rahakott ei ole krüpteeritud.</translation>
    </message>
    <message>
        <source>The supplied passphrases do not match.</source>
        <translation>Sisestatud salafraasid ei kattu.</translation>
    </message>
    <message>
        <source>Wallet unlock failed</source>
        <translation>Rahakoti lahtilukustamine ebaõnnestus</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption was incorrect.</source>
        <translation>Rahakoti dekrüpteerimiseks sisestatud salafraas ei ole õige.</translation>
    </message>
    <message>
        <source>Wallet passphrase was successfully changed.</source>
        <translation>Rahakoti salafraas on edukalt vahetatud.</translation>
    </message>
    <message>
        <source>Warning: The Caps Lock key is on!</source>
        <translation>Hoiatus:Klaviatuuri suurtähelukk on peal.</translation>
    </message>
</context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>Wallet</source>
        <translation>Rahakott</translation>
    </message>
    <message>
        <source>&amp;Overview</source>
        <translation>&amp;Ülevaade</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation>Kuva rahakoti üld-ülevaade</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>&amp;Saada</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation>&amp;Võta vastu</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation>Sirvi tehingute ajalugu</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>V&amp;älju</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation>Väljumine</translation>
    </message>
    <message>
        <source>&amp;Options...</source>
        <translation>&amp;Valikud...</translation>
    </message>
    <message>
        <source>&amp;Show / Hide</source>
        <translation>&amp;Näita / Peida</translation>
    </message>
    <message>
        <source>&amp;Encrypt Wallet...</source>
        <translation>&amp;Krüpteeri Rahakott</translation>
    </message>
    <message>
        <source>&amp;Change Passphrase...</source>
        <translation>&amp;Salafraasi muutmine</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation>Rahakoti krüpteerimise salafraasi muutmine</translation>
    </message>
    <message>
        <source>Sign &amp;message...</source>
        <translation>Signeeri &amp;sõnum</translation>
    </message>
    <message>
        <source>&amp;Verify message...</source>
        <translation>&amp;Kontrolli sõnumit...</translation>
    </message>
    <message>
        <source>&amp;Debug window</source>
        <translation>&amp;Silumise aken</translation>
    </message>
    <message>
        <source>Open debugging and diagnostic console</source>
        <translation>Ava debugimise ja diagnostika konsool</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Fail</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Seaded</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Abi</translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to the Gridcoin network</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n second(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s) ago</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation>Ajakohane</translation>
    </message>
    <message>
        <source>Catching up...</source>
        <translation>Jõuan järgi...</translation>
    </message>
    <message>
        <source>Sent transaction</source>
        <translation>Saadetud tehing</translation>
    </message>
    <message>
        <source>Incoming transaction</source>
        <translation>Sisenev tehing</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
        <translation>Rahakott on &lt;b&gt;krüpteeritud&lt;/b&gt; ning hetkel &lt;b&gt;suletud&lt;/b&gt;</translation>
    </message>
    </context>
<context>
    <name>ClientModel</name>
    <message>
        <source>Network Alert</source>
        <translation>Võrgu Häire</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Quantity:</source>
        <translation>Kogus:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation>Baiti:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Summa:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Tasu:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>Peale tehingutasu:</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation>Vahetusraha:</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Kogus</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Kuupäev</translation>
    </message>
    <message>
        <source>Confirmations</source>
        <translation>Kinnitused</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Kinnitatud</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Aadress</translation>
    </message>
    <message>
        <source>Copy address</source>
        <translation>Kopeeri aadress</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>Kopeeri märgis</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Kopeeri summa</translation>
    </message>
    <message>
        <source>Copy transaction ID</source>
        <translation>Kopeeri tehingu ID</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation>Kopeeri kogus</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation>Kopeeri tehingutasu</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation>Kopeeri baidid</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation>Kopeeri vahetusraha</translation>
    </message>
    <message>
        <source>yes</source>
        <translation>jah</translation>
    </message>
    <message>
        <source>no</source>
        <translation>ei</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(märgis puudub)</translation>
    </message>
    <message>
        <source>(change)</source>
        <translation>(vahetusraha)</translation>
    </message>
</context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation>Muuda aadressi</translation>
    </message>
    <message>
        <source>&amp;Label</source>
        <translation>&amp;Märgis</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation>&amp;Aadress</translation>
    </message>
    <message>
        <source>New receiving address</source>
        <translation>Uus vastu võttev aadress</translation>
    </message>
    <message>
        <source>New sending address</source>
        <translation>Uus saatev aadress</translation>
    </message>
    <message>
        <source>Edit receiving address</source>
        <translation>Muuda vastuvõtvat aadressi</translation>
    </message>
    <message>
        <source>Edit sending address</source>
        <translation>Muuda saatvat aadressi</translation>
    </message>
    <message>
        <source>The entered address "%1" is already in the address book.</source>
        <translation>Sisestatud aadress "%1" on juba aadressi raamatus.</translation>
    </message>
    <message>
        <source>Could not unlock wallet.</source>
        <translation>Rahakoti lahtilukustamine ebaõnnestus.</translation>
    </message>
    <message>
        <source>New key generation failed.</source>
        <translation>Uue võtme genereerimine ebaõnnestus.</translation>
    </message>
</context>
<context>
    <name>Intro</name>
    <message numerus="yes">
        <source>%n GB of free space available</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(of %n GB needed)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(%n GB needed for full chain)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>Valikud</translation>
    </message>
    <message>
        <source>&amp;Main</source>
        <translation>&amp;Peamine</translation>
    </message>
    <message>
        <source>&amp;Network</source>
        <translation>&amp;Võrk</translation>
    </message>
    <message>
        <source>Map port using &amp;UPnP</source>
        <translation>Suuna port &amp;UPnP kaudu</translation>
    </message>
    <message>
        <source>Port of the proxy (e.g. 9050)</source>
        <translation>Proxi port (nt 9050)</translation>
    </message>
    <message>
        <source>Minimize instead of exit the application when the window is closed. When this option is enabled, the application will be closed only after selecting Quit in the menu.</source>
        <translation>Sulgemise asemel minimeeri aken. Selle valiku tegemisel suletakse programm Menüüst "Välju" käsuga.</translation>
    </message>
    <message>
        <source>&amp;Display addresses in transaction list</source>
        <translation>Tehingute loetelu &amp;Display aadress</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Aken</translation>
    </message>
    <message>
        <source>Show only a tray icon after minimizing the window.</source>
        <translation>Minimeeri systray alale.</translation>
    </message>
    <message>
        <source>&amp;Minimize to the tray instead of the taskbar</source>
        <translation>&amp;Minimeeri systray alale</translation>
    </message>
    <message>
        <source>M&amp;inimize on close</source>
        <translation>M&amp;inimeeri sulgemisel</translation>
    </message>
    <message>
        <source>&amp;Display</source>
        <translation>&amp;Kuva</translation>
    </message>
    <message>
        <source>User Interface &amp;language:</source>
        <translation>Kasutajaliidese &amp;keel:</translation>
    </message>
    <message>
        <source>&amp;Unit to show amounts in:</source>
        <translation>Summade kuvamise &amp;Unit:</translation>
    </message>
    <message>
        <source>Choose the default subdivision unit to show in the interface and when sending coins.</source>
        <translation>Vali liideses ning müntide saatmisel kuvatav vaikimisi alajaotus.</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Katkesta</translation>
    </message>
    <message>
        <source>default</source>
        <translation>vaikeväärtus</translation>
    </message>
    <message>
        <source>The supplied proxy address is invalid.</source>
        <translation>Sisestatud kehtetu proxy aadress.</translation>
    </message>
    </context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Form</source>
        <translation>Vorm</translation>
    </message>
    <message>
        <source>Immature:</source>
        <translation>Ebaküps:</translation>
    </message>
    <message>
        <source>Total:</source>
        <translation>Kokku:</translation>
    </message>
    </context>
<context>
    <name>QObject</name>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>Client version</source>
        <translation>Kliendi versioon</translation>
    </message>
    <message>
        <source>&amp;Information</source>
        <translation>&amp;Informatsioon</translation>
    </message>
    <message>
        <source>Startup time</source>
        <translation>Käivitamise hetk</translation>
    </message>
    <message>
        <source>Number of connections</source>
        <translation>Ühenduste arv</translation>
    </message>
    <message>
        <source>Block chain</source>
        <translation>Ploki jada</translation>
    </message>
    <message>
        <source>Current number of blocks</source>
        <translation>Plokkide hetkearv</translation>
    </message>
    <message>
        <source>Last block time</source>
        <translation>Viimane ploki aeg</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation>&amp;Ava</translation>
    </message>
    <message>
        <source>&amp;Console</source>
        <translation>&amp;Konsool</translation>
    </message>
    <message>
        <source>Debug log file</source>
        <translation>Silumise logifail</translation>
    </message>
    <message>
        <source>Clear console</source>
        <translation>Puhasta konsool</translation>
    </message>
    <message>
        <source>Estimated total blocks</source>
        <translation>Ligikaudne plokkide kogus</translation>
    </message>
    <message>
        <source>Client name</source>
        <translation>Kliendi nimi</translation>
    </message>
    <message>
        <source>Use up and down arrows to navigate history, and &lt;b&gt;Ctrl-L&lt;/b&gt; to clear screen.</source>
        <translation>Ajaloo sirvimiseks kasuta üles ja alla nooli, ekraani puhastamiseks &lt;b&gt;Ctrl-L&lt;/b&gt;.</translation>
    </message>
    <message>
        <source>Type &lt;b&gt;help&lt;/b&gt; for an overview of available commands.</source>
        <translation>Ülevaateks võimalikest käsklustest trüki &lt;b&gt;help&lt;/b&gt;.</translation>
    </message>
    <message>
        <source>%1 KB</source>
        <translation>%1 B</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Send Coins</source>
        <translation>Müntide saatmine</translation>
    </message>
    <message>
        <source>Inputs...</source>
        <translation>Sisendid...</translation>
    </message>
    <message>
        <source>automatically selected</source>
        <translation>automaatselt valitud</translation>
    </message>
    <message>
        <source>Insufficient funds!</source>
        <translation>Liiga suur summa</translation>
    </message>
    <message>
        <source>Quantity:</source>
        <translation>Kogus:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation>Baiti:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Summa:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Tasu:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>Peale tehingutasu:</translation>
    </message>
    <message>
        <source>Send to multiple recipients at once</source>
        <translation>Saatmine mitmele korraga</translation>
    </message>
    <message>
        <source>Add &amp;Recipient</source>
        <translation>Lisa &amp;Saaja</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation>Puhasta &amp;Kõik</translation>
    </message>
    <message>
        <source>Confirm the send action</source>
        <translation>Saatmise kinnitamine</translation>
    </message>
    <message>
        <source>S&amp;end</source>
        <translation>S&amp;aada</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation>Kopeeri kogus</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Kopeeri summa</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation>Kopeeri tehingutasu</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation>Kopeeri baidid</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation>Kopeeri vahetusraha</translation>
    </message>
    <message>
        <source>Confirm send coins</source>
        <translation>Müntide saatmise kinnitamine</translation>
    </message>
    <message>
        <source>The recipient address is not valid, please recheck.</source>
        <translation>Saaja aadress ei ole kehtiv, palun kontrolli.</translation>
    </message>
    <message>
        <source>The amount to pay must be larger than 0.</source>
        <translation>Makstav summa peab olema suurem kui 0.</translation>
    </message>
    <message>
        <source>The amount exceeds your balance.</source>
        <translation>Summa ületab jäägi.</translation>
    </message>
    <message>
        <source>The total exceeds your balance when the %1 transaction fee is included.</source>
        <translation>Summa koos tehingu tasuga %1 ületab sinu jääki.</translation>
    </message>
    <message>
        <source>Duplicate address found, can only send to each address once per send operation.</source>
        <translation>Ühe saatmisega topelt-adressaati olla ei tohi.</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(märgis puudub)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>A&amp;mount:</source>
        <translation>S&amp;umma:</translation>
    </message>
    <message>
        <source>Pay &amp;To:</source>
        <translation>Maksa &amp;:</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation>Sõnum:</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation>&amp;Märgis</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Kleebi aadress vahemälust</translation>
    </message>
    <message>
        <source>Enter a label for this address to add it to your address book</source>
        <translation>Aadressiraamatusse sisestamiseks märgista aadress</translation>
    </message>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    <message>
        <source>Signatures - Sign / Verify a Message</source>
        <translation>Signatuurid - Allkirjasta / Kinnita Sõnum</translation>
    </message>
    <message>
        <source>&amp;Sign Message</source>
        <translation>&amp;Allkirjastamise teade</translation>
    </message>
    <message>
        <source>You can sign messages with your addresses to prove you own them. Be careful not to sign anything vague, as phishing attacks may try to trick you into signing your identity over to them. Only sign fully-detailed statements you agree to.</source>
        <translation>Omandiõigsuse tõestamiseks saad sõnumeid allkirjastada oma aadressiga. Ettevaatust petturitega, kes üritavad saada sinu allkirja endale saada. Allkirjasta ainult korralikult täidetud avaldusi, millega nõustud.</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Kleebi aadress vahemälust</translation>
    </message>
    <message>
        <source>Enter the message you want to sign here</source>
        <translation>Sisesta siia allkirjastamise sõnum</translation>
    </message>
    <message>
        <source>Copy the current signature to the system clipboard</source>
        <translation>Kopeeri praegune signatuur vahemällu</translation>
    </message>
    <message>
        <source>Sign &amp;Message</source>
        <translation>Allkirjasta &amp;Sõnum</translation>
    </message>
    <message>
        <source>Reset all sign message fields</source>
        <translation>Tühjenda kõik sõnumi allkirjastamise väljad</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation>Puhasta &amp;Kõik</translation>
    </message>
    <message>
        <source>&amp;Verify Message</source>
        <translation>&amp;Kinnita Sõnum</translation>
    </message>
    <message>
        <source>Enter the signing address, message (ensure you copy line breaks, spaces, tabs, etc. exactly) and signature below to verify the message. Be careful not to read more into the signature than what is in the signed message itself, to avoid being tricked by a man-in-the-middle attack.</source>
        <translation>Kinnitamiseks sisesta allkirjastamise aadress, sõnum (kindlasti kopeeri täpselt ka reavahetused, tühikud, tabulaatorid jms) ning allolev signatuur.</translation>
    </message>
    <message>
        <source>Reset all verify message fields</source>
        <translation>Tühjenda kõik sõnumi kinnitamise väljad</translation>
    </message>
    <message>
        <source>Click "Sign Message" to generate signature</source>
        <translation>Allkirja loomiseks vajuta "Allkirjasta Sõnum"</translation>
    </message>
    <message>
        <source>The entered address is invalid.</source>
        <translation>Sisestatud aadress ei ole korrektne</translation>
    </message>
    <message>
        <source>Please check the address and try again.</source>
        <translation>Palun kontrolli aadressi ja proovi uuesti.</translation>
    </message>
    <message>
        <source>The entered address does not refer to a key.</source>
        <translation>Sisestatud aadress ei viita võtmele.</translation>
    </message>
    <message>
        <source>Wallet unlock was cancelled.</source>
        <translation>Rahakoti lahtilukustamine on katkestatud.</translation>
    </message>
    <message>
        <source>Private key for the entered address is not available.</source>
        <translation>Sisestatud aadressi privaatvõti pole saadaval.</translation>
    </message>
    <message>
        <source>Message signing failed.</source>
        <translation>Sõnumi allkirjastamine ebaõnnestus.</translation>
    </message>
    <message>
        <source>Message signed.</source>
        <translation>Sõnum allkirjastatud</translation>
    </message>
    <message>
        <source>The signature could not be decoded.</source>
        <translation>Allkirja polnud võimalik dekodeerida.</translation>
    </message>
    <message>
        <source>Please check the signature and try again.</source>
        <translation>Palun kontrolli allkirja ja proovi uuesti.</translation>
    </message>
    <message>
        <source>The signature did not match the message digest.</source>
        <translation>Allkiri ei vastanud sõnumi krüptoräsile.</translation>
    </message>
    <message>
        <source>Message verification failed.</source>
        <translation>Sõnumi verifitseerimine ebaõnnestus.</translation>
    </message>
    <message>
        <source>Message verified.</source>
        <translation>Sõnum verifitseeritud.</translation>
    </message>
</context>
<context>
    <name>TransactionDesc</name>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Open until %1</source>
        <translation>Avatud kuni %1</translation>
    </message>
    <message>
        <source>%1/offline</source>
        <translation>%1/offline'is</translation>
    </message>
    <message>
        <source>%1/unconfirmed</source>
        <translation>%1/kinnitamata</translation>
    </message>
    <message>
        <source>%1 confirmations</source>
        <translation>%1 kinnitust</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Olek</translation>
    </message>
    <message>
        <source>, has not been successfully broadcast yet</source>
        <translation>, veel esitlemata</translation>
    </message>
    <message numerus="yes">
        <source>, broadcast through %n node(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Kuupäev</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>Allikas</translation>
    </message>
    <message>
        <source>From</source>
        <translation>Saatja</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>tundmatu</translation>
    </message>
    <message>
        <source>To</source>
        <translation>Saaja</translation>
    </message>
    <message>
        <source>own address</source>
        <translation>oma aadress</translation>
    </message>
    <message>
        <source>label</source>
        <translation>märgis</translation>
    </message>
    <message>
        <source>Credit</source>
        <translation>Krediit</translation>
    </message>
    <message numerus="yes">
        <source>matures in %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>not accepted</source>
        <translation>pole vastu võetud</translation>
    </message>
    <message>
        <source>Debit</source>
        <translation>Deebet</translation>
    </message>
    <message>
        <source>Transaction fee</source>
        <translation>Tehingutasu</translation>
    </message>
    <message>
        <source>Net amount</source>
        <translation>Neto summa</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Sõnum</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation>Kommentaar</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Summa</translation>
    </message>
    <message>
        <source>true</source>
        <translation>tõene</translation>
    </message>
    <message>
        <source>false</source>
        <translation>väär</translation>
    </message>
</context>
<context>
    <name>TransactionDescDialog</name>
    <message>
        <source>Transaction details</source>
        <translation>Tehingu üksikasjad</translation>
    </message>
    <message>
        <source>This pane shows a detailed description of the transaction</source>
        <translation>Paan kuvab tehingu detailid</translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation>Kuupäev</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tüüp</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Aadress</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Kogus</translation>
    </message>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Open until %1</source>
        <translation>Avatud kuni %1</translation>
    </message>
    <message>
        <source>Unconfirmed</source>
        <translation>Kinnitamata</translation>
    </message>
    <message>
        <source>Confirmed (%1 confirmations)</source>
        <translation>Kinnitatud (%1 kinnitust)</translation>
    </message>
    <message>
        <source>Generated but not accepted</source>
        <translation>Loodud, kuid aktsepteerimata</translation>
    </message>
    <message>
        <source>Received with</source>
        <translation>Saadud koos</translation>
    </message>
    <message>
        <source>Received from</source>
        <translation>Kellelt saadud</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>Saadetud</translation>
    </message>
    <message>
        <source>Payment to yourself</source>
        <translation>Makse iseendale</translation>
    </message>
    <message>
        <source>Transaction status. Hover over this field to show number of confirmations.</source>
        <translation>Tehingu staatus. Kinnituste arvu kuvamiseks liigu hiire noolega selle peale.</translation>
    </message>
    <message>
        <source>Date and time that the transaction was received.</source>
        <translation>Tehingu saamise kuupäev ning kellaaeg.</translation>
    </message>
    <message>
        <source>Type of transaction.</source>
        <translation>Tehingu tüüp.</translation>
    </message>
    <message>
        <source>Destination address of transaction.</source>
        <translation>Tehingu saaja aadress.</translation>
    </message>
    <message>
        <source>Amount removed from or added to balance.</source>
        <translation>Jäägile lisatud või eemaldatud summa.</translation>
    </message>
</context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Today</source>
        <translation>Täna</translation>
    </message>
    <message>
        <source>This week</source>
        <translation>Käesolev nädal</translation>
    </message>
    <message>
        <source>This month</source>
        <translation>Käesolev kuu</translation>
    </message>
    <message>
        <source>Last month</source>
        <translation>Eelmine kuu</translation>
    </message>
    <message>
        <source>This year</source>
        <translation>Käesolev aasta</translation>
    </message>
    <message>
        <source>Range...</source>
        <translation>Vahemik...</translation>
    </message>
    <message>
        <source>Received with</source>
        <translation>Saadud koos</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>Saadetud</translation>
    </message>
    <message>
        <source>To yourself</source>
        <translation>Iseendale</translation>
    </message>
    <message>
        <source>Mined</source>
        <translation>Mine'itud</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Muu</translation>
    </message>
    <message>
        <source>Min amount</source>
        <translation>Minimaalne summa</translation>
    </message>
    <message>
        <source>Copy address</source>
        <translation>Kopeeri aadress</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>Kopeeri märgis</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Kopeeri summa</translation>
    </message>
    <message>
        <source>Copy transaction ID</source>
        <translation>Kopeeri tehingu ID</translation>
    </message>
    <message>
        <source>Edit label</source>
        <translation>Märgise muutmine</translation>
    </message>
    <message>
        <source>Show transaction details</source>
        <translation>Kuva tehingu detailid</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Kinnitatud</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Kuupäev</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tüüp</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Silt</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Aadress</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Kogus</translation>
    </message>
    <message>
        <source>Range:</source>
        <translation>Ulatus:</translation>
    </message>
    <message>
        <source>to</source>
        <translation>saaja</translation>
    </message>
</context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>An error occurred while setting up the RPC port %u for listening on IPv6, falling back to IPv4: %s</source>
        <translation>RPC pordi %u kuulamiseks seadistamisel ilmnes viga IPv6'l, lülitumine tagasi IPv4'le : %s</translation>
    </message>
    <message>
        <source>An error occurred while setting up the RPC port %u for listening on IPv4: %s</source>
        <translation>RPC pordi %u kuulamiseks seadistamisel ilmnes viga IPv4'l: %s</translation>
    </message>
    <message>
        <source>Usage:</source>
        <translation>Kasutus:</translation>
    </message>
    <message>
        <source>List commands</source>
        <translation>Käskluste loetelu</translation>
    </message>
    <message>
        <source>Get help for a command</source>
        <translation>Käskluste abiinfo</translation>
    </message>
    <message>
        <source>Warning: -paytxfee is set very high! This is the transaction fee you will pay if you send a transaction.</source>
        <translation>Hoiatus: -paytxfee on seatud väga kõrgeks! See on sinu poolt makstav tehingu lisatasu.</translation>
    </message>
    <message>
        <source>Warning: wallet.dat corrupt, data salvaged! Original wallet.dat saved as wallet.{timestamp}.bak in %s; if your balance or transactions are incorrect you should restore from a backup.</source>
        <translation>Hoiatus: toimus wallet.dat faili andmete päästmine! Originaal wallet.dat nimetati kaustas %s ümber wallet.{ajatempel}.bak'iks, jäägi või tehingute ebakõlade puhul tuleks teha backup'ist taastamine.</translation>
    </message>
    <message>
        <source>Warning: error reading wallet.dat! All keys read correctly, but transaction data or address book entries might be missing or incorrect.</source>
        <translation>Hoiatus: ilmnes tõrge wallet.dat faili lugemisel! Võtmed on terved, kuid tehingu andmed või aadressiraamatu kirjed võivad olla kadunud või vigased.</translation>
    </message>
    <message>
        <source>Failed to listen on any port. Use -listen=0 if you want this.</source>
        <translation>Pordi kuulamine nurjus. Soovikorral kasuta -listen=0.</translation>
    </message>
    <message>
        <source>To use the %s option</source>
        <translation>%s valiku kasutamine</translation>
    </message>
    <message>
        <source>You must set rpcpassword=&lt;password&gt; in the configuration file:
%s
If the file does not exist, create it with owner-readable-only file permissions.</source>
        <translation>rpcpassword=&lt;password&gt; peab sätete failis olema seadistatud:?
%s?
Kui seda faili ei ole, loo see ainult-omanikule-lugemiseks faili õigustes.</translation>
    </message>
    <message>
        <source>Invalid amount for -paytxfee=&lt;amount&gt;: '%s'</source>
        <translation>-paytxfee=&lt;amount&gt; jaoks vigane kogus: '%s'</translation>
    </message>
    <message>
        <source>Wallet %s resides outside data directory %s.</source>
        <translation>Rahakott %s paikenb väljaspool kataloogi %s.</translation>
    </message>
    <message>
        <source>wallet.dat corrupt, salvage failed</source>
        <translation>wallet.dat fail on katki, päästmine ebaõnnestus</translation>
    </message>
    <message>
        <source>Invalid -proxy address: '%s'</source>
        <translation>Vigane -proxi aadress: '%s'</translation>
    </message>
    <message>
        <source>Cannot resolve -bind address: '%s'</source>
        <translation>Tundmatu -bind aadress: '%s'</translation>
    </message>
    <message>
        <source>Cannot resolve -externalip address: '%s'</source>
        <translation>Tundmatu -externalip aadress: '%s'</translation>
    </message>
    <message>
        <source>Error loading blkindex.dat</source>
        <translation>Viga faili blkindex.dat laadimisel</translation>
    </message>
    <message>
        <source>Error loading wallet.dat: Wallet corrupted</source>
        <translation>Viga wallet.dat käivitamisel. Vigane rahakkott</translation>
    </message>
    <message>
        <source>Error loading wallet.dat: Wallet requires newer version of Gridcoin</source>
        <translation>Viga faili wallet.dat laadimisel: rahakott vajab Gridcoin'i uuemat versiooni.</translation>
    </message>
    <message>
        <source>Wallet needed to be rewritten: restart Gridcoin to complete</source>
        <translation>Rahakott on vaja üle kirjutada: käivita Gridcoin uuesti toimingu lõpetamiseks</translation>
    </message>
    <message>
        <source>Error loading wallet.dat</source>
        <translation>Viga wallet.dat käivitamisel</translation>
    </message>
    <message>
        <source>Loading addresses...</source>
        <translation>Aadresside laadimine...</translation>
    </message>
    <message>
        <source>Unable to bind to %s on this computer (bind returned error %d, %s)</source>
        <translation>Selle arvutiga ei ole võimalik siduda %s külge (katse nurjus %d, %s tõttu)</translation>
    </message>
    <message>
        <source>Sending...</source>
        <translation>Saatmine...</translation>
    </message>
    <message>
        <source>Invalid amount</source>
        <translation>Kehtetu summa</translation>
    </message>
    <message>
        <source>Unknown network specified in -onlynet: '%s'</source>
        <translation>Kirjeldatud tundmatu võrgustik -onlynet'is: '%s'</translation>
    </message>
    <message>
        <source>Insufficient funds</source>
        <translation>Liiga suur summa</translation>
    </message>
    <message>
        <source>Loading block index...</source>
        <translation>Klotside indeksi laadimine...</translation>
    </message>
    <message>
        <source>Loading wallet...</source>
        <translation>Rahakoti laadimine...</translation>
    </message>
    <message>
        <source>Cannot write default address</source>
        <translation>Tõrge vaikimisi aadressi kirjutamisel</translation>
    </message>
    <message>
        <source>Rescanning...</source>
        <translation>Üleskaneerimine...</translation>
    </message>
    <message>
        <source>Done loading</source>
        <translation>Laetud</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Tõrge</translation>
    </message>
</context>
</TS>